@@ -20,14 +20,13 @@
 
 using namespace Dasher;
 
-class IOstreamDasherEdit : public Dasher::CDashEditbox
-{
- public:
-  IOstreamDasherEdit( CDasherInterface *_interface, std::ostream* os = &std::cout );
+class IOstreamDasherEdit:public Dasher::CDashEditbox {
+public:
+  IOstreamDasherEdit(CDasherInterface * _interface, std::ostream * os = &std::cout);
   ~IOstreamDasherEdit();
 
   void write_to_file();
-  void get_new_context(std::string& str, int max);
+  void get_new_context(std::string & str, int max);
   void unflush();
   void output(symbol Symbol);
   void flush(symbol Symbol);
@@ -36,21 +35,21 @@ class IOstreamDasherEdit : public Dasher::CDashEditbox
 
   void SetEncoding(Opts::FileEncodingFormats Encoding);
   void SetFont(std::string Name, long Size);
-  bool SaveAs( const std::string filename, bool a );
-  bool Save( bool a=false);
-  bool Open( const std::string filename );
+  bool SaveAs(const std::string filename, bool a);
+  bool Save(bool a = false);
+  bool Open(const std::string filename);
 
   void TimeStampNewFiles(bool Value);
 
   void kill_flush();
 
-  void set_display_encoding( int _enc );
+  void set_display_encoding(int _enc);
 
- protected:
+protected:
   int flush_count;
   CDasherInterface *interface;
 
-  std::ostream *outstream;
+  std::ostream * outstream;
 
   int enc;
   char encstr[256];
