@@ -1,6 +1,9 @@
 #include <iostream>
 #include <string>
+#include <gtk/gtk.h>
 
 void setup_speech();
 void teardown_speech();
-void SPEAK_DAMN_YOU(std::string *speech);
+void SPEAK_DAMN_YOU(const gchar * speech);
+void repeat_speech();
+
