@@ -7,6 +7,11 @@
 /////////////////////////////////////////////////////////////////////////////
 
 #include "WinCommon.h"
+#include <guiddef.h>
+#include <Oleacc.h>
+#include <Textstor.h>
+#include <Msctf.h>
+#include <Msaatext.h>
 
 #include "DasherWindow.h"
 
@@ -32,6 +37,17 @@ using namespace std;
 
 #define IDT_TIMER1 200
 
+#ifdef PJC_EXPERIMENTAL
+
+// Bits an pieces from pjc playing with text service framework stuff
+
+bool g_bInCallback(false);
+HWND g_hWnd;
+IAccClientDocMgr *g_pMgr;
+VOID CALLBACK WinEventProc(HWINEVENTHOOK hWinEventHook, DWORD event, HWND hwnd, LONG idObject, LONG idChild, DWORD dwEventThread, DWORD dwmsEventTime);
+
+#endif
+
 CDasherWindow::CDasherWindow()
 :Splash(0), m_pToolbar(0), m_pEdit(0), m_pSlidebar(0), m_pSplitter(0), m_pDasher(0), m_pCanvas(0) 
 {
@@ -46,6 +62,57 @@ CDasherWindow::CDasherWindow()
 //    wc.m_wc.lpszClassName = WndClassName;      // Not in a resource - does not require translation
 	wc.m_wc.hIconSm        = m_hIconSm;
 	
+#ifdef PJC_EXPERIMENTAL
+
+// Create an acc manager foobar
+
+  CLSID MyClsid;
+
+  MyClsid.Data1 = 0xFC48CC30;
+  MyClsid.Data2 = 0x4F3E;
+  MyClsid.Data3 = 0x4fa1;
+  MyClsid.Data4[0] = 0x80;
+  MyClsid.Data4[1] = 0x3B;
+  MyClsid.Data4[2] = 0xAD;
+  MyClsid.Data4[3] = 0x0E;
+  MyClsid.Data4[4] = 0x19;
+  MyClsid.Data4[5] = 0x6A;
+  MyClsid.Data4[6] = 0x83;
+  MyClsid.Data4[7] = 0xB1;
+
+  IID MyIid;
+ 
+  MyIid.Data1 = 0x4C896039;
+  MyIid.Data2 = 0x7B6D;
+  MyIid.Data3 = 0x49e6;
+  MyIid.Data4[0] = 0xA8;
+  MyIid.Data4[1] = 0xC1;
+  MyIid.Data4[2] = 0x45;
+  MyIid.Data4[3] = 0x11;
+  MyIid.Data4[4] = 0x6A;
+  MyIid.Data4[5] = 0x98;
+  MyIid.Data4[6] = 0x29;
+  MyIid.Data4[7] = 0x2B;
+
+  
+  HRESULT Foo = CoCreateInstance(MyClsid, 0, CLSCTX_ALL, MyIid, (void**)&g_pMgr);
+  g_pMgr->AddRef();
+  // Set up callback for WinEvents
+  
+  HWINEVENTHOOK hEventHook;
+
+  hEventHook = SetWinEventHook(EVENT_OBJECT_FOCUS,             // Get all events.
+                               EVENT_OBJECT_FOCUS,
+                               GetModuleHandle(NULL), // Use this module
+                               WinEventProc,
+                               0,                     // All processes
+                               0,                     // All threads
+                               WINEVENT_OUTOFCONTEXT);
+  if(!hEventHook) {
+    MessageBox(NULL, L"Initialisation of WinEvent hook failed");
+  }
+#endif
+
 }
 
 HWND CDasherWindow::Create()
@@ -75,13 +142,18 @@ HWND CDasherWindow::Create()
   // Create Widgets
   m_pDasher = new CDasher(hWnd);
 
+  // Create a CAppSettings
+  m_pAppSettings = new CAppSettings(m_pDasher, hWnd);
+
   m_pEdit = new CEdit();
-  m_pEdit->Create(hWnd);
+  m_pEdit->Create(hWnd, m_pAppSettings->GetBoolParameter(APP_BP_TIME_STAMP));
+
+#ifdef PJC_EXPERIMENTAL
+  g_hWnd = m_pEdit->GetHwnd();
+#endif
 
   m_pToolbar = new CToolbar(hWnd, m_pDasher);
 
-
-
   // Set an object to handle edit events
   m_pDasher->SetEdit(m_pEdit);
 
@@ -100,9 +172,6 @@ HWND CDasherWindow::Create()
   if (!hSplitter)
 	  return 0;
 
-  // Create a CAppSettings
-  m_pAppSettings = new CAppSettings(m_pDasher, hWnd);
-
   // Add extra control nodes
 
   m_pDasher->RegisterNode( Dasher::CControlManager::CTL_USER, "Speak", -1 );
@@ -776,4 +845,67 @@ void CDasherWindow::PopulateSettings() {
  //   WinMenu.SetStatus(ID_SAVE_AS_UTF16_LITTLE,      false, m_pDasher->GetLongParameter(LP_FILE_ENCODING)==Opts::UTF16LE);
   //  WinMenu.SetStatus(ID_SAVE_AS_UTF16_BIG,         false, m_pDasher->GetLongParameter(LP_FILE_ENCODING)==Opts::UTF16BE);
   }
-}
\ No newline at end of file
+}
+
+
+#ifdef PJC_EXPERIMENTAL
+
+VOID CALLBACK WinEventProc(HWINEVENTHOOK hWinEventHook, DWORD event, HWND hwnd, LONG idObject, LONG idChild, DWORD dwEventThread, DWORD dwmsEventTime) {
+
+  if(hwnd == g_hWnd)
+    return;
+
+  if(!g_bInCallback) {
+    g_bInCallback = true;
+    VARIANT MyV;
+    IAccessible *pMyAccessible;
+    VariantInit(&MyV);
+
+    if( AccessibleObjectFromEvent( hwnd, idObject, idChild, &pMyAccessible, &MyV) != S_OK) {
+      // Do nothing
+    }
+    else {
+      VARIANT MyV2;
+      VariantInit(&MyV2);
+
+      pMyAccessible->get_accRole(MyV, &MyV2);
+
+//      if(MyV2.iVal == ROLE_SYSTEM_TEXT) {
+        ITextStoreAnchor *pAnchor(NULL);
+      HRESULT MyFoo = g_pMgr->GetFocused(IID_ITextStoreAnchor, (IUnknown **)(&pAnchor));
+pAnchor->AddRef();
+//        pMyAccessible->QueryInterface(IID_ITextStoreAnchor, (void **)(&pAnchor));
+//        MessageBox(NULL, L"Got Text", L"Foo", MB_OK);
+HRESULT MyBar;
+
+if(pAnchor) {
+  IAnchor *pStart;
+  IAnchor *pEnd;
+
+
+HRESULT MyLock;
+HRESULT MyLock2;
+
+IEnumUnknown *pMyEnum;
+
+g_pMgr->GetDocuments(&pMyEnum);
+
+if(pMyEnum) {
+  pMyEnum->AddRef();
+}
+
+  MyLock = pAnchor->RequestLock(TS_LF_READWRITE, &MyLock2);
+
+  MyBar = pAnchor->InsertTextAtSelection(TF_IAS_NOQUERY, L"Foo", 3, &pStart, &pEnd);
+//MessageBox(NULL, L"Got Text", L"Foo", MB_OK);
+    }
+
+      VariantClear(&MyV2);
+    }
+
+    VariantClear(&MyV);
+    g_bInCallback = false;
+  }
+};
+
+#endif
\ No newline at end of file
