@@ -174,23 +174,14 @@ LRESULT CCanvas::OnPaint(UINT message, WPARAM wParam, LPARAM lParam, BOOL& bHand
     PAINTSTRUCT ps;
     BeginPaint(&ps);
 
-    ///             Screen->SetNextHDC(hdc);
-    //m_pDasherInterface->Redraw();
     m_pScreen->Display();
-    //      if (firstwindow==true) 
-    //      {
-    //              m_pScreen->DrawMousePosBox(0,m_iMousePosDist);
-    //      } 
-    //      else if (secondwindow==true) 
-    //      {
-    //              m_pScreen->DrawMousePosBox(1,m_iMousePosDist);
-    //      }
+
     EndPaint(&ps);
-	bHandled = TRUE;
+
+	  bHandled = TRUE;
     return 0;
 }
 
-
 LRESULT CCanvas::OnKeyUp(UINT message, WPARAM wParam, LPARAM lParam, BOOL& bHandled)
 {
 	bHandled = TRUE;
@@ -221,99 +212,36 @@ LRESULT CCanvas::OnKeyDown(UINT message, WPARAM wParam, LPARAM lParam, BOOL& bHa
   TCHAR tmpAutoOffset[128];
 #endif
 
+  bHandled = TRUE;
 
-	bHandled = TRUE;
-
-	switch (wParam) 
-	{
-		if(m_pDasherInterface->GetBoolParameter(BP_KEY_CONTROL) == true)
-		{
-	case VK_UP:
-		if(forward == true) 
-		{
-			buttonnum++;
-			if(buttonnum == 9) 
-			{
-				buttonnum = 0;
-			}
-			while(keycoords[buttonnum * 2] == NULL) 
-			{
-				buttonnum++;
-				if(buttonnum == 9) 
-				{
-					buttonnum = 0;
-				}
-			}
-			m_pDasherInterface->DrawGoTo(keycoords[buttonnum * 2], keycoords[buttonnum * 2 + 1]);
-		}
-		else 
-		{
-			m_pDasherInterface->GoTo(keycoords[0], keycoords[1]);
-		}
-		return 0;
-		break;
-	case VK_DOWN:
-		if(backward == true) 
-		{
-			buttonnum--;
-			if(buttonnum == -1) 
-			{
-				buttonnum = 8;
-			}
-			while(keycoords[buttonnum * 2] == NULL) 
-			{
-				buttonnum--;
-				if(buttonnum == -1) 
-				{
-					buttonnum = 8;
-				}
-			}
-			m_pDasherInterface->DrawGoTo(keycoords[buttonnum * 2], keycoords[buttonnum * 2 + 1]);
-		}
-		else 
-		{
-			m_pDasherInterface->GoTo(keycoords[2], keycoords[3]);
-		}
-		return 0;
-	case VK_LEFT:
-		if(select == true) 
-		{
-			m_pDasherInterface->GoTo(keycoords[buttonnum * 2], keycoords[buttonnum * 2 + 1]);
-			m_pDasherInterface->DrawGoTo(keycoords[buttonnum * 2], keycoords[buttonnum * 2 + 1]);
-		}
-		else 
-		{
-			m_pDasherInterface->GoTo(keycoords[4], keycoords[5]);
-		}
-		return 0;
-	case VK_RIGHT:
-		m_pDasherInterface->GoTo(keycoords[6], keycoords[7]);
-		return 0;
-		break;
-		}      // end if key control
+	switch (wParam) {
+  // Space, for start/stop events etc.
 	case VK_SPACE:
-		startspace();
+    m_pDasherInterface->KeyDown(GetTickCount(), 0);
 		return 0;
+
 #ifdef _DEBUG
 	case VK_F11:
 		wsprintf(tmpAutoOffset, TEXT("yAutoValue: %d"), m_pDasherInterface->GetAutoOffset());
 		MessageBox(tmpAutoOffset, TEXT("Auto-offset Value"), MB_OK);
 		return 0;
 #endif
-	case VK_F12:
+
+  case VK_F12:
 		centrecursor();
 		return 0;
-	case VK_SHIFT:
 
+  // Boost keys
+	case VK_SHIFT:
 		if(lParam ^ REPEAT) // ignore auto-repeat
 			m_pDasherInterface->SetLongParameter(LP_BOOSTFACTOR, 175);
-
 		return 0;
-
 	case VK_CONTROL:
 		if(lParam ^ REPEAT) // ignore auto-repeat
 			m_pDasherInterface->SetLongParameter(LP_BOOSTFACTOR, 25);
 		return 0;
+
+  // Button mode keys
   case 0x41:
     m_pDasherInterface->KeyDown(GetTickCount(), 1);
     return 0;
@@ -347,32 +275,15 @@ LRESULT CCanvas::OnLButtonDown(UINT message, WPARAM wParam, LPARAM lParam, BOOL&
 
 	OutputDebugString(TEXT("Canvas::LButtonDown\n"));
 
-	//   startturbo = GetTickCount();
-	
-	//SetFocus();
-	
-	/*
-	lbuttonheld = 1;
-	lastlbutton = GetTickCount();
-	direction = !direction;
-	enabletime = 1;
-	if(startonleft == false) {
-	return 0;
-	}
-	StartStop();*/
-
+  // FIXME - what does this do - please document
 	LPARAM lp = GetMessageExtraInfo();
 	if (lp == 0xFF515702)
-		return 0;
+		return 0; 
+  // ---
 
-	if ( m_pDasherInterface->GetBoolParameter(BP_START_MOUSE) ) 
-	{
-		if (m_pDasherInterface->GetBoolParameter(BP_DASHER_PAUSED))
-			m_pDasherInterface->Unpause(GetTickCount());
-		else
-			m_pDasherInterface->PauseAt(0, 0);
-	}
-//	else if ( m_pDasherInterface->GetBoolParameter(BP_START_STYLUS)  ) 
+  m_pDasherInterface->KeyDown(GetTickCount(), 100);
+
+  //	else if ( m_pDasherInterface->GetBoolParameter(BP_START_STYLUS)  ) 
 //	{
 //		// DJW - for the time being we only do stylus mode if not BP_START_MOUSE 
 //
@@ -382,7 +293,6 @@ LRESULT CCanvas::OnLButtonDown(UINT message, WPARAM wParam, LPARAM lParam, BOOL&
 
 	m_bButtonDown = true;
 	return 0;
-
 }
 
 LRESULT CCanvas::OnLButtonUp(UINT message, WPARAM wParam, LPARAM lParam, BOOL& bHandled)
@@ -621,18 +531,6 @@ void CCanvas::DoFrame()
 	m_pDasherInterface->NewFrame(dwTicks);//TapOn(imousex, imousey, GetTickCount());
 }
 
-void CCanvas::startspace() {
-   if(m_pDasherInterface->GetBoolParameter(BP_START_SPACE) == false) {
-    return;
-  }
-  else {
-    if(m_pDasherInterface->GetBoolParameter(BP_DASHER_PAUSED))
-      m_pDasherInterface->Unpause(GetTickCount());
-    else
-      m_pDasherInterface->PauseAt(0, 0);
-  }
-}
-
 void CCanvas::centrecursor() {
   POINT mousepos;
   mousepos.x = m_pScreen->GetWidth() / 2;
